@@ -1,5 +1,4 @@
-from datetime import datetime
-
+from django.utils.timezone import now
 from django.db.models import Manager
 
 
@@ -11,5 +10,4 @@ class PublicManager(Manager):
 
     def published(self):
         """Return public posts that are not in the future."""
-        return self.get_query_set().filter(status__gte=2,
-                                           publish__lte=datetime.now())
+        return self.get_query_set().filter(status__gte=2, publish__lte=now())
